import { PublicKey } from '@solana/web3.js';
import { Group } from './accounts/group';
import { MangoAccount } from './accounts/mangoAccount';
import { MangoClient } from './client';
export interface LiqorPriceImpact {
    Coin: {
        val: string;
    };
    'Oracle Price': {
        val: number;
    };
    'On-Chain Price': {
        val: number;
    };
    'Future Price': {
        val: number;
    };
    'V4 Liq Fee': {
        val: number;
    };
    Liabs: {
        val: number;
    };
    'Liabs Slippage': {
        val: number;
    };
    Assets: {
        val: number;
    };
    'Assets Slippage': {
        val: number;
    };
}
export interface PerpPositionsToBeLiquidated {
    Market: {
        val: string;
    };
    Price: {
        val: number;
    };
    'Future Price': {
        val: number;
    };
    'Notional Position': {
        val: number;
    };
}
export interface AccountEquity {
    Account: {
        val: PublicKey;
    };
    Equity: {
        val: number;
    };
}
export interface Risk {
    assetRally: {
        title: string;
        data: LiqorPriceImpact[];
    };
    assetDrop: {
        title: string;
        data: LiqorPriceImpact[];
    };
    usdcDepeg: {
        title: string;
        data: LiqorPriceImpact[];
    };
    usdtDepeg: {
        title: string;
        data: LiqorPriceImpact[];
    };
    perpRally: {
        title: string;
        data: PerpPositionsToBeLiquidated[];
    };
    perpDrop: {
        title: string;
        data: PerpPositionsToBeLiquidated[];
    };
    marketMakerEquity: {
        title: string;
        data: AccountEquity[];
    };
    liqorEquity: {
        title: string;
        data: AccountEquity[];
    };
}
export declare function computePriceImpactOnJup(amount: string, inputMint: string, outputMint: string): Promise<{
    outAmount: number;
    priceImpactPct: number;
}>;
export declare function getOnChainPriceForMints(mints: string[]): Promise<number[]>;
export declare function getPriceImpactForLiqor(group: Group, mangoAccounts: MangoAccount[]): Promise<LiqorPriceImpact[]>;
export declare function getPerpPositionsToBeLiquidated(group: Group, mangoAccounts: MangoAccount[]): Promise<PerpPositionsToBeLiquidated[]>;
export declare function getEquityForMangoAccounts(client: MangoClient, group: Group, mangoAccounts: PublicKey[]): Promise<AccountEquity[]>;
export declare function getRiskStats(client: MangoClient, group: Group, change?: number): Promise<Risk>;
